The source repository for this project can be found at:

   https://opendev.org/openstack/horizon

Pull requests submitted through GitHub are not monitored.

To start contributing to OpenStack, follow the steps in the contribution guide
to set up and use Gerrit:

   https://docs.openstack.org/contributors/code-and-documentation/quick-start.html

Bugs should be filed on Launchpad:

https://bugs.launchpad.net/horizon

For more specific information about contributing to this repository, see the
horizon contributor guide:

   https://docs.openstack.org/horizon/latest/contributor/contributing.html
